(module-name (scheme lazy))
(require kawa.lib.misc)
(require kawa.lib.std_syntax)
(include "lazy-exports")
